==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateListBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateListBuilder extends CertificateListFluentImpl<CertificateListBuilder> implements VisitableBuilder<CertificateList,CertificateListBuilder>{
  public CertificateListBuilder() {
    this(false);
  }
  public CertificateListBuilder(Boolean validationEnabled) {
    this(new CertificateList(), validationEnabled);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateList(), validationEnabled);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent,CertificateList instance) {
    this(fluent, instance, false);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent,CertificateList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CertificateListBuilder(CertificateList instance) {
    this(instance,false);
  }
  public CertificateListBuilder(CertificateList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  CertificateListFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateList build() {
    CertificateList buildable = new CertificateList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateListBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateListBuilder extends CertificateListFluent<CertificateListBuilder> implements VisitableBuilder<CertificateList,CertificateListBuilder>{
  public CertificateListBuilder() {
    this(false);
  }
  public CertificateListBuilder(Boolean validationEnabled) {
    this(new CertificateList(), validationEnabled);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateList(), validationEnabled);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent,CertificateList instance) {
    this(fluent, instance, false);
  }
  public CertificateListBuilder(CertificateListFluent<?> fluent,CertificateList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new CertificateList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CertificateListBuilder(CertificateList instance) {
    this(instance,false);
  }
  public CertificateListBuilder(CertificateList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new CertificateList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  CertificateListFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateList build() {
    CertificateList buildable = new CertificateList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
